#include "my color.h"
/*
	This program modual contains the Initializing and Modification code to 
	colorize the windows and scroll bars.
*/

void	set_color(aWindow)	/* 	When a new window has been created, I'll initialize 
								the  new window's colors to these default values, change 
								them as you see fit.  See Inside Macintosh Vol 5, page 202,
								The Window Color Tables paragraph for a detailed explaination
								of what is going on here.  Each window should get its own
								unique Color Table.
							*/
CWindowPtr	aWindow;
{
CWindowPeek		peek;
ControlHandle	control;

	GetPort(&savedPort);		/* Save the Graf Port */
/*
	in order to display  a window in color, I must first create a color table that 
	will contain color definitions for all the parts of the window.  Each window 
	should have its own unique color table.  If we don't give each window a 
	unique color table, then color changes in one window will affect all 
	the windows. Read Inside Mac Vol. 5, page V-48 for a definition of the color 
	table record. Page V-134 contains even more info on color tables and on how
	the color manager works and utilizes a color table.
*/

/*		First get some RAM to store the Window's ColorTable in. A window has five 
		parts that can be colored. 
		I will need RAM for the Color table and RAM for the 5 color specs necessary
		to hold the color info for each of the window parts */
		
	new_color_handle = (CTabHandle)NewHandle(sizeof(ColorTable) + (5 * sizeof(ColorSpec)));	/* allocate a new color Table for this Window */
	if(!new_color_handle)	/* check the handle to be certain that the Mac OS actually gave me some RAM */
		{ SysBeep(10); return; } /* no memory can be allocated for this color table */


/*		Now initialize the ColorTable to these values to start with, don't worry, I
			just made the RGB numbers up, they have no special significance.
		Page V-202 of Inside Macintosh gives detailed info on the definitions 
			of the fields and the values they can take on 
*/

	(*new_color_handle)->ctSize = 4;	/* This is the Color Table Size parameter, there are 5 parts to a window that can be colored, they are numbered 0 thru 4 */

	(*new_color_handle)->ctTable[0].value = wContentColor;	/* The "value" fields in 
																the color table tell 
																the Color manager which 
																part of the window this
																color definition record 
																is for. I hope you know 
																what the content region 
																of a window is */
	(*new_color_handle)->ctTable[0].rgb.red = 0;
	(*new_color_handle)->ctTable[0].rgb.green = 56;
	(*new_color_handle)->ctTable[0].rgb.blue = 56789;
	
	(*new_color_handle)->ctTable[1].value = wFrameColor;	/* define the Window Frame color */
	(*new_color_handle)->ctTable[1].rgb.red = 0;
	(*new_color_handle)->ctTable[1].rgb.green = 6789;
	(*new_color_handle)->ctTable[1].rgb.blue = 20000;
	
	(*new_color_handle)->ctTable[2].value = wTextColor;		/* this is for the text in the title bar, not the text edit text */
	(*new_color_handle)->ctTable[2].rgb.red = 65535;
	(*new_color_handle)->ctTable[2].rgb.green = 65535;
	(*new_color_handle)->ctTable[2].rgb.blue = 65535;
	
	(*new_color_handle)->ctTable[3].value = wHiliteColor;	/* this is for hiliting the window' title bar when the window is activated */
	(*new_color_handle)->ctTable[3].rgb.red = 0;
	(*new_color_handle)->ctTable[3].rgb.green = 32434;
	(*new_color_handle)->ctTable[3].rgb.blue = 0;
	
	(*new_color_handle)->ctTable[4].value = wTitleBarColor;
	(*new_color_handle)->ctTable[4].rgb.red = 65535;
	(*new_color_handle)->ctTable[4].rgb.green = 0;
	(*new_color_handle)->ctTable[4].rgb.blue = 20000;
	
	HLock(new_color_handle);				/* Lock it just in case SetWinColor de-references the Handle */
	SetWinColor(aWindow, new_color_handle);	/* now give the color manager the color table to be associated with the window */
	HUnlock(new_color_handle);				/* Now that SetWinColor is done, I'll unlock the handle */

/*
	Since the window is now nicely colored, I'll also color the controls .....
*/
	peek = (CWindowPeek)aWindow;
	control = peek->controlList;	/* start with the window's first control .....*/
	while(control)					/* for each control, set its respective parts 
										to these color values */
	{
	/*		first create a color table for the control */
		new_color_handle = (CTabHandle)NewHandle(sizeof(ColorTable) + (4 * sizeof(ColorSpec)));	/* allocate a new color Table for this control */
		if(!new_color_handle)
			{ SysBeep(10); return; } /* no memory can be allocated for this color table */

	/* 
		now initialize the elements of the color table to these values.
		(Page V-218 of Inside Macintosh gives details of the Control's color table
		and how the SetCtlColor routine works.)
	 */
		(*new_color_handle)->ctSize = 3;						/* The Color Table Size is for 4 elements, numbered 0 thru 3 */
		(*new_color_handle)->ctTable[0].value = cFrameColor;	/* set the Control's Frame color to this value */
		(*new_color_handle)->ctTable[0].rgb.red = 0;
		(*new_color_handle)->ctTable[0].rgb.green = 0;
		(*new_color_handle)->ctTable[0].rgb.blue = 0;
		
		(*new_color_handle)->ctTable[1].value = cBodyColor;
		(*new_color_handle)->ctTable[1].rgb.red = 23456;
		(*new_color_handle)->ctTable[1].rgb.green = 30000;
		(*new_color_handle)->ctTable[1].rgb.blue = 65535;
	
		(*new_color_handle)->ctTable[2].value = cTextColor;	/* this is for any text in the control, scroll bars usually don't have text in them */
		(*new_color_handle)->ctTable[2].rgb.red = 65535;
		(*new_color_handle)->ctTable[2].rgb.green = 0;
		(*new_color_handle)->ctTable[2].rgb.blue = 65535;
	
		(*new_color_handle)->ctTable[3].value = cThumbColor;
		(*new_color_handle)->ctTable[3].rgb.red = 0;
		(*new_color_handle)->ctTable[3].rgb.green = 65535;
		(*new_color_handle)->ctTable[3].rgb.blue = 0;
		
		HLock(new_color_handle);				/* Lock it just in case SetWinColor de-references the Handle */
		SetCtlColor(control, new_color_handle);	/* now give the color manager the color table */
		HUnlock(new_color_handle);				/* Now that SetWinColor is done, I'll unlock the handle */
	
		control = (*control)->nextControl;
	}

	SetPort(savedPort);			/* restore the original Graf Port */
}

